==> Mojo-Webqq-1.8.7.tar.gz: Mojo-Webqq-1.8.7/lib/Mojo/Webqq/Plugin/ZiYue.pm <==

package Mojo::Webqq::Plugin::ZiYue;
$Mojo::Webqq::Plugin::ZiYue::PRIORITY = 1;


my @reply =qw(
巧言令色，鲜矣仁！
不患人之不己知，患不知人也。
温故而知新，可以为师矣。
君子不器。
君子周而不比，小人比而不周。
学而不思则罔，思而不学则殆。
攻乎异端，斯害也已。
夷狄之有君，不如诸夏之亡也。
自既灌而往者，吾不欲观之矣。
事君尽礼，人以为谄也。
《关雎》，乐而不淫，哀而不伤。
里仁为美。择不处仁，焉得知？
唯仁者能好人，能恶人。
苟志于仁矣，无恶也。
朝闻道，夕死可矣。
放于利而行，多怨。
君子喻于义，小人喻于利。
见贤思齐焉，见不贤而内自省也。
父母在，不远游，游必有方。
三年无改于父之道，可谓孝矣。
古者言之不出，耻躬之不逮也。
以约失之者鲜矣。
君子欲讷于言而敏于行。
德不孤，必有邻。
晏平仲善与人交，久而敬之。
伯夷、叔齐不念旧恶，怨是用希。
雍也可使南面。
谁能出不由户？何莫由斯道也？
人之生也直，罔之生也幸而免。
觚不觚，觚哉！觚哉！
自行束修以上，吾未尝无诲焉。
天生德于予，恒 其如予何？
仁远乎哉？我欲仁，斯仁至矣。
君子坦荡荡，小人长戚戚。
兴于诗，立于礼，成于乐。
民可使由之，不可使知之。
三年学，不至于谷，不易得也。
不在其位，不谋其政。
学如不及，犹恐失之。
凤鸟不至，河不出图，吾已矣夫！
吾未见好德如好色者也。
语之而不惰者，其回也与！
三军可夺帅也，匹夫不可夺志也。
岁寒，然后知松柏之后凋也。
知者不惑，仁者不忧，勇者不惧。
从我于陈、蔡者，皆不及门也。
论笃是与，君子者乎？色庄者乎？
听讼，吾犹人也。必也使无讼乎？
鲁卫之政，兄弟也。
如有王者，必世而后仁。
君子和而不同，小人同而不和。
君子泰而不骄，小人骄而不泰。
刚、毅、木、讷近仁。
善人教民七年，亦可以即戎矣。
以不教民战，是谓弃之。
士而怀居，不足以为士矣。
贫而无怨难，富而无骄易。
其言之不怍，则为之也难。
君子上达，小人下达。
古之学者为己，今之学者为人。
君子耻其言之过其行。
不患人之不己知，患其不能也。
骥不称其力，称其德也。
上好礼，则民易使也。
由！知德者鲜矣。
人无远虑，必有近忧。
已矣乎！吾未见好德如好色者也。
躬自厚而薄责于人，则远怨矣。
君子疾没世而名不称焉。
君子求诸己，小人求诸人。
君子矜而不争，群而不党。
君子不以言举人，不以人废言。
巧言乱德。小不忍，则乱大谋。
人能弘道，非道弘人。
过而不改，是谓过矣。
当仁，不让于师。
君子贞而不谅。
事君，敬其事而后其食。
有教无类。
道不同不相为谋。
辞达而已矣。
性相近也，习相远也。
唯上知与下愚不移。
乡原，德之贼也。
道听而涂说，德之弃也。
巧言令色，鲜矣仁。
年四十而见恶焉，其终也已。
);
sub call {
    my $client = shift;
    $client->on(receive_message=>sub{
        my($client,$msg)=@_;
        return if not $msg->allow_plugin;
        return if $msg->content !~ /(子\s*曰|论\s*语|者\s*也)/;
        $msg->allow_plugin(0);
        my $key_word = $1;$key_word=~s/\s+//;
        my $reply = $reply[int rand($#reply+1)];
        $reply=~s/%/$key_word/g;
        $client->reply_message($msg,$reply,sub{$_[1]->msg_from("bot")}) if $reply;
    });
}
1;

==> Mojo-Webqq-2.0.1.tar.gz: Mojo-Webqq-2.0.1/lib/Mojo/Webqq/Plugin/ZiYue.pm <==

package Mojo::Webqq::Plugin::ZiYue;
$Mojo::Webqq::Plugin::ZiYue::PRIORITY = 1;


my @reply =qw(
巧言令色，鲜矣仁！
不患人之不己知，患不知人也。
温故而知新，可以为师矣。
君子不器。
君子周而不比，小人比而不周。
学而不思则罔，思而不学则殆。
攻乎异端，斯害也已。
夷狄之有君，不如诸夏之亡也。
自既灌而往者，吾不欲观之矣。
事君尽礼，人以为谄也。
《关雎》，乐而不淫，哀而不伤。
里仁为美。择不处仁，焉得知？
唯仁者能好人，能恶人。
苟志于仁矣，无恶也。
朝闻道，夕死可矣。
放于利而行，多怨。
君子喻于义，小人喻于利。
见贤思齐焉，见不贤而内自省也。
父母在，不远游，游必有方。
三年无改于父之道，可谓孝矣。
古者言之不出，耻躬之不逮也。
以约失之者鲜矣。
君子欲讷于言而敏于行。
德不孤，必有邻。
晏平仲善与人交，久而敬之。
伯夷、叔齐不念旧恶，怨是用希。
雍也可使南面。
谁能出不由户？何莫由斯道也？
人之生也直，罔之生也幸而免。
觚不觚，觚哉！觚哉！
自行束修以上，吾未尝无诲焉。
天生德于予，恒 其如予何？
仁远乎哉？我欲仁，斯仁至矣。
君子坦荡荡，小人长戚戚。
兴于诗，立于礼，成于乐。
民可使由之，不可使知之。
三年学，不至于谷，不易得也。
不在其位，不谋其政。
学如不及，犹恐失之。
凤鸟不至，河不出图，吾已矣夫！
吾未见好德如好色者也。
语之而不惰者，其回也与！
三军可夺帅也，匹夫不可夺志也。
岁寒，然后知松柏之后凋也。
知者不惑，仁者不忧，勇者不惧。
从我于陈、蔡者，皆不及门也。
论笃是与，君子者乎？色庄者乎？
听讼，吾犹人也。必也使无讼乎？
鲁卫之政，兄弟也。
如有王者，必世而后仁。
君子和而不同，小人同而不和。
君子泰而不骄，小人骄而不泰。
刚、毅、木、讷近仁。
善人教民七年，亦可以即戎矣。
以不教民战，是谓弃之。
士而怀居，不足以为士矣。
贫而无怨难，富而无骄易。
其言之不怍，则为之也难。
君子上达，小人下达。
古之学者为己，今之学者为人。
君子耻其言之过其行。
不患人之不己知，患其不能也。
骥不称其力，称其德也。
上好礼，则民易使也。
由！知德者鲜矣。
人无远虑，必有近忧。
已矣乎！吾未见好德如好色者也。
躬自厚而薄责于人，则远怨矣。
君子疾没世而名不称焉。
君子求诸己，小人求诸人。
君子矜而不争，群而不党。
君子不以言举人，不以人废言。
巧言乱德。小不忍，则乱大谋。
人能弘道，非道弘人。
过而不改，是谓过矣。
当仁，不让于师。
君子贞而不谅。
事君，敬其事而后其食。
有教无类。
道不同不相为谋。
辞达而已矣。
性相近也，习相远也。
唯上知与下愚不移。
乡原，德之贼也。
道听而涂说，德之弃也。
巧言令色，鲜矣仁。
年四十而见恶焉，其终也已。
);
sub call {
    my $client = shift;
    $client->on(receive_message=>sub{
        my($client,$msg)=@_;
        return if not $msg->allow_plugin;
        return if $msg->content !~ /(子\s*曰|论\s*语|者\s*也)/;
        $msg->allow_plugin(0);
        my $key_word = $1;$key_word=~s/\s+//;
        my $reply = $reply[int rand($#reply+1)];
        $reply=~s/%/$key_word/g;
        $client->reply_message($msg,$reply,sub{$_[1]->from("bot")}) if $reply;
    });
}
1;
